@@ -115,5 +115,14 @@ if __name__ == '__main__':
     # test_prompt_form_advanced()
     # test_dict_to_table()
     # pyautogui.prompt(text="Apellido", title="field 1/3", default="mondongo")
-    # print(test_menu_5())
-    test_continue_or_exit()
+    print(test_menu_1())
+    print('---------------------')
+    print(test_menu_2())
+    print('---------------------')
+    print(test_menu_3())
+    print('---------------------')
+    print(test_menu_4())
+    print('---------------------')
+    print(test_menu_5())
+    print('---------------------')
+    # test_continue_or_exit()
